@@ -4,9 +4,9 @@ data("GasolineYield", package = "zoib")
 
 # zoib: fixed
 eg.fixed <- zoib(yield ~ temp + as.factor(batch)| 1, data=GasolineYield,
-                 joint = FALSE,  random = 0, EUID = 1:nrow(d),
+                 joint = FALSE,  random = 0, EUID = 1:nrow(GasolineYield),
                  zero.inflation = FALSE, one.inflation = FALSE,
-                 n.iter = 151, n.thin = 2, n.burn=1, seeds=c(1,2,3),n.chain=3)
+                 n.iter = 51, n.thin = 2, n.burn=1, seeds=c(1,2,3),n.chain=3)
 sample1 <- eg.fixed$coeff
 
 
